---
Summary: Allow categories in other cards from being listed in field of a card
Status: Done
---

# Description

When a card contains an identifier to another card, or a list of other cards in a field, allow those to be treated as collections. When a card contains a field called 'items', those items are added to a collection with the same index as the card. For instance:

```md
---
Summary: Example summary
Index: card0
---

# Depends

-   [[card1]]
-   [[card2]]

# Items

-   [[card3]]
-   [[card4]]
```

would create a collection `card0.depends` which would have the cards `card1` and `card2` in it, as well as a collection `card0`.

For now, the level of header is ignored.

# Cucumber

**GIVEN** a field of a card containing card(s) within double square brackets
**WHEN** that field is searched as a collection by `sbl`
**THEN** those cards are returned

**GIVEN** a field 'Items' of a card containing card(s) within double square brackets
**WHEN** the card index is searched as a collection by `sbl`
**THEN** those cards are returned
